@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
 
 package Tangence::Client;
 
@@ -10,20 +10,13 @@ use warnings;
 
 use base qw( Tangence::Stream );
 
-our $VERSION = '0.20_001';
+our $VERSION = '0.04';
 
 use Carp;
 
 use Tangence::Constants;
-use Tangence::Types;
 use Tangence::ObjectProxy;
 
-use Future;
-
-use List::Util qw( max );
-
-use constant VERSION_MINOR_MIN => 2;
-
 =head1 NAME
 
 C<Tangence::Client> - mixin class for building a C<Tangence> client
@@ -90,6 +83,7 @@ The following methods are provided by this mixin.
 
 # Accessors for Tangence::Message decoupling
 sub objectproxies { shift->{objectproxies} ||= {} }
+sub schemata      { shift->{schemata} ||= {} }
 
 =head2 $rootobj = $client->rootobj
 
@@ -134,11 +128,6 @@ It takes the following named arguments:
 
 =over 8
 
-=item do_init => BOOL
-
-Ignored. Maintained for compatibility with previous version that allowed this
-to be disabled.
-
 =item on_root => CODE
 
 Optional callback to be invoked once the root object has been returned. It
@@ -153,12 +142,6 @@ be passed a L<Tangence::ObjectProxy> to the registry.
 
  $on_registry->( $registry )
 
-=item version_minor_min => INT
-
-Optional minimum minor version to negotiate with the server. This can be used
-to require a higher minimum version than the client module itself supports, in
-case the application requires features in a newer version than that.
-
 =back
 
 =cut
@@ -168,61 +151,24 @@ sub tangence_connected
    my $self = shift;
    my %args = @_;
 
-   my $version_minor_min = max( VERSION_MINOR_MIN, $args{version_minor_min} || 0 );
-
    $self->request(
-      request => Tangence::Message->new( $self, MSG_INIT )
-         ->pack_int( VERSION_MAJOR )
-         ->pack_int( VERSION_MINOR )
-         ->pack_int( $version_minor_min ),
+      request => Tangence::Message->new( $self, MSG_GETROOT )
+         ->pack_any( $self->identity ),
 
       on_response => sub {
          my ( $message ) = @_;
-         my $code = $message->code;
+         my $type = $message->type;
 
-         if( $code == MSG_INITED ) {
-            my $major = $message->unpack_int();
-            my $minor = $message->unpack_int();
-
-            $self->minor_version( $minor );
-            $self->tangence_initialised( %args );
-         }
-         elsif( $code == MSG_ERROR ) {
-            my $msg = $message->unpack_str();
-            print STDERR "Cannot initialise stream - error $msg";
-         }
-         else {
-            print STDERR "Cannot initialise stream - code $code\n";
-         }
-      },
-   );
-}
-
-sub tangence_initialised
-{
-   my $self = shift;
-   my %args = @_;
-
-   my $request = Tangence::Message->new( $self, MSG_GETROOT );
-   TYPE_ANY->pack_value( $request, $self->identity );
-
-   $self->request(
-      request => $request,
-
-      on_response => sub {
-         my ( $message ) = @_;
-         my $code = $message->code;
-
-         if( $code == MSG_RESULT ) {
-            $self->rootobj( TYPE_OBJ->unpack_value( $message ) );
+         if( $type == MSG_RESULT ) {
+            $self->rootobj( $message->unpack_obj() );
             $args{on_root}->( $self->rootobj ) if $args{on_root};
          }
-         elsif( $code == MSG_ERROR ) {
+         elsif( $type == MSG_ERROR ) {
             my $msg = $message->unpack_str();
             print STDERR "Cannot get root object - error $msg";
          }
          else {
-            print STDERR "Cannot get root object - code $code\n";
+            print STDERR "Cannot get root object - code $type\n";
          }
       }
    );
@@ -232,18 +178,18 @@ sub tangence_initialised
 
       on_response => sub {
          my ( $message ) = @_;
-         my $code = $message->code;
+         my $type = $message->type;
 
-         if( $code == MSG_RESULT ) {
-            $self->registry( TYPE_OBJ->unpack_value( $message ) );
+         if( $type == MSG_RESULT ) {
+            $self->registry( $message->unpack_obj() );
             $args{on_registry}->( $self->registry ) if $args{on_registry};
          }
-         elsif( $code == MSG_ERROR ) {
+         elsif( $type == MSG_ERROR ) {
             my $msg = $message->unpack_str();
             print STDERR "Cannot get registry - error $msg";
          }
          else {
-            print STDERR "Cannot get registry - code $code\n";
+            print STDERR "Cannot get registry - code $type\n";
          }
       }
    );
@@ -305,24 +251,25 @@ sub get_by_id
 sub make_proxy
 {
    my $self = shift;
-   my ( $id, $classname, $smashdata ) = @_;
+   my ( $id, $class, $smashdata ) = @_;
 
    if( exists $self->objectproxies->{$id} ) {
       croak "Already have an object id $id";
    }
 
-   my $class;
-   if( defined $classname ) {
-      $class = $self->peer_hasclass->{$classname}->[0];
-      defined $class or croak "Cannot construct a proxy for class $classname as no meta exists";
+   my $schema;
+   if( defined $class ) {
+      $schema = $self->schemata->{$class};
+      defined $schema or croak "Cannot construct a proxy for class $class as no schema exists";
    }
 
    my $obj = $self->objectproxies->{$id} =
       Tangence::ObjectProxy->new(
-         client => $self,
-         id     => $id,
+         conn => $self,
+         id   => $id,
 
-         class => $class,
+         class  => $class,
+         schema => $schema,
 
          on_error => $self->on_error,
       );
@@ -332,27 +279,11 @@ sub make_proxy
    return $obj;
 }
 
-=head1 SUBCLASSING METHODS
+# Keep perl happy; keep Britain tidy
+1;
 
-These methods are intended for implementation classes to override.
-
-=cut
-
-=head2 $f = $client->new_future
-
-Returns a new L<Future> instance for basing asynchronous operations on.
-
-=cut
-
-sub new_future
-{
-   return Future->new;
-}
+__END__
 
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
-
-=cut
-
-0x55AA;
