@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2010 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2011 -- leonerd@leonerd.org.uk
 
 package Tangence::Server::Context;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 use Carp;
 
@@ -17,11 +17,11 @@ use Tangence::Constants;
 sub new
 {
    my $class = shift;
-   my ( $conn, $token ) = @_;
+   my ( $stream, $token ) = @_;
 
    return bless {
-      conn  => $conn,
-      token => $token,
+      stream => $stream,
+      token  => $token,
    }, $class;
 }
 
@@ -31,10 +31,10 @@ sub DESTROY
    $self->{responded} or croak "$self never responded";
 }
 
-sub connection
+sub stream
 {
    my $self = shift;
-   return $self->{conn};
+   return $self->{stream};
 }
 
 sub respond
@@ -44,8 +44,7 @@ sub respond
 
    $self->{responded} and croak "$self has responded once already";
 
-   my $conn = $self->{conn};
-   $conn->respond( $self->{token}, $message );
+   $self->stream->respond( $self->{token}, $message );
 
    $self->{responded} = 1;
 
@@ -57,7 +56,7 @@ sub responderr
    my $self = shift;
    my ( $msg ) = @_;
 
-   $self->respond( Tangence::Message->new( $self->{conn}, MSG_ERROR )
+   $self->respond( Tangence::Message->new( $self->stream, MSG_ERROR )
       ->pack_str( $msg )
    );
 }
